#!/bin/bash -e

BUNDLE_ID="com.github.aliencoweatcake.imageviewer"
APP_PATH=$(osascript -e "POSIX path of (path to application id \"${BUNDLE_ID}\")" | sed 's|:/$||')

TMP_DIR=""
function command_exists() {
    type "${1}" &> /dev/null
}
function extract_duti() {
    TMP_DIR="$(mktemp -d)"
    cat << EOF | base64 -d | bzip2 -d -c > "${TMP_DIR}/duti"
QlpoOTFBWSZTWf1eD5QAbMn/////////////////////////////////////////////4GHd3WGvfafXpjZw74MO+zoQB9mWmr3utW2e47vfZo7755SRB69L76Xie49dL2PvvrlzvufZ9W69e9XjZ7zXahIxWW0qB7u6IzWbe7yepevXPh9nwAewVYw1UrZWmBJvXdNb
HnAd2q+s972W089vO3YbVvd9rrT3fYZ3udfbLPppbc7vXOTW4eg53eh16HoH0+gD6elKHXOWGfYHrkF2GWug6Og+q0VyfYpu+7yk53eIeeW+cN29vu7zzuu881AACPe+Lx6F6yvptsvfY3MqiiQvkMBeHrdRYDm6lKElKu4zuWnfT057OuEqIggAjTCGABDCZGCaE8mg
ZBkNNNDRoZDTQNBPIZAAMmTIamaJskwZAATBMDTQ0DQAaaAJ6TAJgTCm0glEk0mRoJgEyYCZMIxGEYjJiaZNT0AEzTRphA1NoBMU9PSYIwqe0YKeRptTFU/0yYNIGABE9DSPCExlGTAnoNTTwhkm0aFQanoQIEBMCDSGmQTExMTSbIp/qp6aR+qe1T9J5MpP1JvVNGj0
eqNNMT9SaemKNBp4p6R6T9Sepmpp7SntU0eU9Qepk9Rmpp6jR+k0aj0gbSZplAAyZAAAAk1IhCNTTQ1J5NMTAmkPQT1NTxqp40yp+Q0aaYVPJ6DUbKepmqeKfoyap+qZlPynhT1RnqnpsmRR5Jk9MCGIZPU0jHip+mknptFPKe0kPE1P1Gk09Mmappo9TT1NqHlBEqFB
J+pppMNAU9oUfpR5Gp5JtNNqm9EynhNNNT0mZRtBknqPRqNqaabU9NI0M1PTU9Q9DCh4owg9Mk8mUyDMpkAMg9RphPUGEwh7RRkD9IajaEBUkhBACNEYhMaNNBoBMZBGNCNNPUwRoyNMhkDQyDTKPI1PVHtNMQNTZTaaTNNSeTak9TxkamRhNoQbU9JqbTTamp+kPSbU
eoGgaBoNRob1Rs+1s43QNxUn4J4Lx3jchnMTR1GwVm5hmt6UuYZbLla1IpDAe5oEQHsv1f2H3ceI4c0Q8zPmK06vho71w9dLQi+QI6SsjIFpILRS4ZAlSUN7J2nkZoduE0Q/Fz8B+0twuUKqOAaVUINSQ3Hj5RhazZkXqJ1Vaiy8KuD1gBCyLiEcSSQhcdBApZpqUUNZ
dPblpyWv7b33D8DLRqFVTKqNdqNJaqaGqqiqKaVapRlUoKsppUpi1VFVVDBYKJSlLKFFqjS2WWrbF+aO53Ru77HqVSvZG9yMMETj2VEdTSnH4PomwWvxq8u5Gd+FzFjmVjwcj0PYRgP5W1mLckgKPRAvcysRUNMZ37iuaNx7hc5oNyau0retnyXW+MbSadAEUa6mwZ0L
qLJA6eIOmgCh2UVVqiSBaTlIPwuVrBcHsSvM5duLVJiqQ4tLNxZwzjS9r2Lj/SLT69SThaJVJMWM7HsrG7816jIJJYYT5n6HaZGh8RxA5FJJSsIGZSSJxro7Isvefe2YYEmWohhJvaxZRWRaLRUhTenlmJcvpu7lqY17tbne/y9/vfs/z/E0/id5/H1eWlp3l0Wikvj1
7VMeeo+XtcKjGdetWWvvZH7PGMzOby90zoxqrF76JWKKCRRKH5S44ikd2cM4Njdgxxy3zbMlTLuWlV96r7d7+bfOC5lpzcvRUvuwvg41A93QzepGryrmBgmAoaoGRQLqwrxhusMZku5nZm/Gf2pUZ9YmgV6k409Q832xg2XRaRmX9gb4c11Be9CYvcnui9oPXFpv3Cnu
y73h70tO9r88rngjAeWdBigoVxMAkyRANhRDqsMoLkdCBDzq6gKMzjE/hjFxXjNpmU/Deepd+Ln0fp9rRz+wuYPD/XE63T685YRsvku28nRNzPbU7RDZtDEiydC5Z17WExMVlTS+tc9JTVf2xjPKLd0jdo2AuNQfTza2xzrbebey15FOGltwWK3AeFtQjXRbAsfwThpb
I4TiJD6vyzijaemLrRTjPh+M6e8dc9TjeJyFV+vLpf3ub8hZptX6BjnnD5vfLu/nqz2q9e7M4M+ib/9IwnBepLfTK/9HNZ7ZF7G7Y0+nbyww8BY788Mq71TNdLRUfnVZD0wqgJzmNGNqlDFOy4tEpAUMmGbU41r4VA/EZzPvu9x7+3c1nrI0xLaalkUpA2bmTBA69k1/
2uJ+Xown6KFtHc27pLl6f/tW9B/otMPiIVD5ne2sBpflO2TzDNnJISGxex996ZJNWWenbCcE4rI6glDYmOJ3VMk5n0p56q8WaBatoNGuFy1avSwz1DQrZCqiEIRVUiV++qjtdznZ1FNFFeLo332rLPJt5KxXvJUUJRRRKUY2/G05z3mjRR0NnVVk6emmc5PkuGMYt7uF
HwYx7+uEK7+jVV30YwpplKUN9JHxjHAZdCUnxjER8HwJS2MpNHf61Gk+fBnOE6/wJznfyZKaa6qu/poxyltpSnKVUpRjGMfKuylJ9mGWk2WUss60snObSkkpakpPyak5znp5qKMEpSlc2+33Pgb7dFT3BCkIFQEoUCIiiqLaqGiqf8/r1LjFFGBSooqqoiIiiiNVSKKu
LBxs2siiqLSUNUNVSqInLyi5UMGHAQyZFBiQzECadptNvyHI77MSZmSHG95UDe6tHO7axMdRUSGjOLzLb7tbYkn6dJ1drCGQRv1bvTbRW/zHQeSgX6AWEUXMRQHrYoNMFTXQ8S1EDOMgUwORqiSykPNsQosrFEYMQFBQEYKbzKoeF/VUOXZ+cgZ9jg1XxwdGzs+HradP
ovK8HS3A8PH1nW8qXgS2K1UWXm7HgyybIjHjt61abtPyOo3WnPufJ/2zX3usb1gTzzJvntFITYQhTAWQSzJNmVUJfVoCzGIbZFg1UkyYDhUAtGS7Ckgf0eTqE89x465z+z+XbZ5QNDDT0uperXOu95Y7E/zTCHtMaDMwnSsJN/0xe0gbDQned1JRLHKcM4GntORi2mO3
xeENXegb93Ct3HOdtRmtrxyAb3ibMMfpONvZU6yRt1UbZWc6ghz9FxmFHTbncCl4XPz8OgpOh2C5/5WBdBdK1oXdwEo0r4Gec+2mMYag2DYaMRitxz8DDRszq53sVqzZ7Cl3B0ND02TlXbuyyDiNRp52DXhXx5Wqar1zQxDWIxlWOZUIKoWReLRr6mQJxg+nk6Oft+TV
pDAL6aLttoXM2Psbmg2na2+mI2WYUjTdGdmxLM27d7JiwuwZEvZU3GqMzBNJ+ltNbY546o5SENA3A16clG1xa0qqydZatbCdljw1Yhcnjzpzw7hFBysg15Ot4EjCtUO5xpRjSzDCm3hSBOqXkDXIdfLnVkTMdslIpSDbi22fuqMdUc1EguzugX91gutm0zrUbrR2vWhg
MRvl2rqVVsMcUAco3jnW3WgBogAMANBCoDlACovbD0vq/EVpCKuchJR0LASEfGXqHg5GDH9AVRC2ywoijYNhAwZVVAoZCkkCkhUSAKHK+FQbMBh8VDATyqdAxYZXrPVaEoXDH1btg20e6W3/iEbsN5vdrv6LC6oiWTd73N05hf3SOdlIn022zbenFuZzG7BGYEXSNogv
KA2qt4veda1nC1LShEAkYUQXhD+Hyn+X5H8WE874X8/1fedXyfRafUeRwDV2mxUKRYiSLFRFXkqjqZJppVUOzmDOeE4MSjkJFb+ohLXZw0U8hJVJdJuVVMjYMeWsSyCPEfKsszyK1rB6fi0F0PlpZNBcoFRLNMMzyh0SVrVSINedtl0OFhj5+segq6vL1COOXsEWtEx3
3qxdCcrGDyiPKm+UcwoIJBNNO3qqqqREVii4NXrgNkbUVhVm3BvYVlVmYsUJRATlPXKwGf6QIK+Bd6rNb0HxxX8VTB2UEYba0XU8tfY33F6tdESRl3qJLWIbDYXHNcFYjxkFUHkiDbm4s6UKmX6HKQNkiwDsQtKGwCM5CqPQu9Z7pgEOh00bhA9R3nU9peGsEAZNuicv
F5WJeIBioIDfjq8F0vQ6fvOk11posZ1f3OQswHoYLquDqrInlKkbgSjfa2FITyXh1qVJHHedfad1berEQsopbxsiKpXRFoCKiXiAdZjdnSmqk1vk8Lx2bhIzCpI42pMlByVSSa4oYUbW3oGdck2rCGgwKJ0YlA/QGbVm/ZAhc7mjOhLnkc35XmYT1LPujg/d6+tovW1/
icPeZTu72nLTAGFtSnPewtZzNS6aKLlJHlKhJPXeLddDwaTFdYNrQnGvnM5wKUp3DmFh8NQ/SU9M1VjMkM5Ukj79FngKWUpEhxMAH0fHrYOj60RVwXnfbz7/LvIAgBEVSyBGCWKiCQQpPvpHh2w5gxmAfpg1g3fPN5w0tepkw3W7ywL6WjHUrAwrRovfIKGAeYYYpJD7
fRc/LSBpN+VCTMIWEBOEIcIS0OdYKAshRcuWh8M4ZgJS3qAm0RgIQGAtjA3MQEMVEkIjEqQvqQ7OoSH9/NctufYfl7v6Hc9rt+Tzk12tsHN1m1NjsdB42GyVCTNgoKIkFgoaMIcqagLNOOXy1S4OG4EoDM3Hm2h/zNUn8UHV5uuzHBzPtiefanaqaa35/n/f5SOw+3hz
Hr9/v+WL+meeEevNWFlQcGVHKUOM5n6SnjPStReuYKfsOHXG6YLMTpX1mRgYD2joVnTc7mXL2IyL9FVWUjABR56DyR5ItD1Ih+rKNb3j6gWBbPiC8Oa0RcGEcwYArmDM9ZevZyl5gZVy4uNexvkGowaONWPE1zNZjWZMrEszlmJTIzln77Be0V6imYz1m4asT4NTXqdE
qKfHotJc/8rkxrylGi0l5ZRUVCGZIoUhBwhA+Ae5KEqIvI6/I8/6P8+H31tp+m3T41Ofv1v66vgzft9yERIUFCfxrDlqWK49a9zpGvBUHYT4wOwEsckVwhqwUEJebNPhnisqc8mJmSbwt7lmgSHFfHPLlB0AzYGIeypdTrdP60vJZnOe7wn73vvp+4+B33WZtHgM3cqs
qJRRbE7q1iV74aTeKJQFjQejzSi2LVFZLnXZ/RUfmSrhXLr+v0fZ3yH+Hd6OF2DtGAa1ZBpkyZ1jgS4CguchG6ZCcl3tQNkjhKEZdldFawS53u02mfAttfTen4V7ZH0vHUTehKQVU4urQ9B2VEg0kTl8huPQnpIoeySqPpVWEN20lSlnyS1C87OuvmKReVoDwo3ghA+g
CAiFAg4WgqvTDq7dR5W5ZMM1J8+08e1srwwREcKM+OiwWQw0VmKYahP2Q16NXRo7Zb8+VXJXOPxxHHJacXytXu2TJS/ZoswpfCCKIQYvCliXo+KPBVYoJGSQi8QUPKwaMhGUZKSj0KQEnlGJKSRHI8QCxeHqkhKMSxECjEgQD1QNJUMAVioSSSlJkgZPDzIUxrDIM2GO
GJk3abXpG9WxtVZYmRlaGyTBCNwozNhJx7CyV9S4basqsUW9IWhu0MmQiwggIlIaGmap3uGnW2Wa+Urzla16lMOpwvfXs4Hn8LZu+qsdJZwDK2rnsBiyG8dokh1nks9gN4m3SWTMb78axdFPGSGtjurUMIcD/5UMk1MPY2ulxr7WtZDMqSRN9VEOHrXKiKUaNHzHFfBL
Qvr7fgtw2STDMdpad321b/LSVUC1UEWHP6tQwqLWUjTAnb2CAqYCJxsVfpRFL9E5oi9pOb23JV41+/SbMHbjNaMhNQQBZJFgH+tOzR/R3Vg9peiSGDMLFBJyghAzJA/SZlUDHG+ru1TVUgf1q8PH4z2l1fNHgOJo7LdcGzEHb7uhEW1wV/uKJ3XSZXm/Ew/wxPkr0Zai
ZUV9K4xaiUJQuSND1c67jrTf5/K/Gt4d4iISe9m3gu5psFP5Nr+eD9uyddv1OZ3arr3arjs7IHckORZ2rbiC8dbVRwqQ2bYbJUwYqN/lss8046yTKKjoqiASq1oEQP6Yy6BbRiLYFe1C1qBcIwlFJ2KpWq+rArxY6MIcXI+Ts3+ftC/suHHVBrxFSiRUilUN2Qb0MArM
sM3iprxwsx+PB6vjgM08f90+rxO1Zy8V8vpXbyeVgejdCZe2LIR5HqA2hqqQcAaBQCPES0NyyJLhcpDs1jBTL5pPU7fG7g3JKHtzcjk+4zSaCjO0vhavGYPjU+s1hlWUS5Sih2Yl6y4zvu6g2+I+VzvkkwI+HgTUzULKZxYiQ0J7pAA3fLQgRoV0PagoRNZnP+YHBuSZ
dH+dZF+vpP6Xb6+T3IIDWPz6UcTDDQJKyTm2mi7Urhuubem52m8eTB8EUUlQYNj4Fa0rSVQesCVZNDe3CsesLpBMrsNjC4BsnJKK8UqRYwQVMr0FmffFuJ9lt1kw4Mdq1cPFuTMza70yeV/Uar+5YuIp3tY7Rf9bfdWT+9yzbaz2nEtevgt3L09pfi0+m0QmDUDwgeXh
TuFlYyGtTO6ULfSRWTwsdmLtiLNGXr7N3wynflVhm9o7AqCQjQaL9yTLEdIupqyzAx61L+/sqcwpfEyQz+isBfHt3ljLtmZ9d3WRsXLEwB0cPD0mDrulsb3wT69xX5mMwnbuRBpXC9OtE532KZItohAaVUaUoK3AKUPE0Hdj7+sol7AkQCWCoVAqAM7169LitMVrijhj
HLSNqNMZBSnewW07NnGexGVW35NvLvnr8tP5m3bx+b3G4b0pSZSufoyLYM/e/z8zjS7hq8n8c7nWR4pvyMPvo7BW1PjnduYO26btsKrJHblVL2vWYuk/djsVJp3ijisJ9KSuxTv6Nlv+NQ3G8fT0d50o8Re5mP+j9gIyk8mTwe4tKku0vioLGB0W65midIWI0fedQfBw
CWodAtQGgneV9DeRu+fiOWJeLp97mXqncnxu78h371eVNOT45oGtOoR3kUVSlFeFxURGZYzZjKkfxnMfJ1/EUtGvNTZ47TQtxwtFqL3K7m9NjY/N2hvvXYSFVXol2N5EKjGIQBeG9RHrsJSKlmCqegsgGoM8uKRLCEQ51zdzLEi0DoRCJzwoQgbRlQ+ICjBCOzzautz9
BeaxevXr4xjGMYxjGMZylKUpSlKUpSlKUpSlKUpSjGMYxjGEIQxxxzZvg+9NWHiTZVxmvb8WuyvPvvFTyMCl6MfYH+NewKEIyEIFdsgfSyszlWTuzR1nWmwhVV5epp5wOX9Asu2O2DbO3k56Z52DNOt+f8S35WHAB/Y8wYWoZ0fqZNCe3C9HyDT7W8IgGxCRBcbihQRG
wrBvmz/mnr22EpGqKvGprmiYk+bTHmStp/300l2NLV01PDXXVXqrkZBoMU9ZRW4puOxWqkKnuA43HMw9RuNlfP5smcsNO911q2Zyub6fHVcCCnfS/u/e3e73x1PwPLP2uNY/7XFG5SIldVarWfqP7+Eq1YWl17bmp/CXpFEfTFoQasftcbvvlb3fGHvzvC7AKK7xcO5z
hbVyAPOcXMw+WjwzmuiUEb5FN0B3MACWaLnBAOxHAFlVCCss4USivyNYvgOrB70bByN13+UxpngLgvbSVYekawBzWQD1zZhyCOtPPZaC8fX5zT6/Q6+UjfKj2iGU4yoiKKwUSGs2IOEFN+0hgkn0GyDZaAqIi8GgpUpJlyZ7Hmb/s+PjmLmfji5aA8LpKNZXrkKfLnSn
eHlhLnG1HR8xxfH49xii6kmpTUqq+A+P8EJGqvGzIpJCoa3Q4JKQhuFoY1yibvkwLQCPF64mh8SbtGA/aQM8aNJA2wPh1VHmEjEAECrHH1j6Tt7uzG/gUQE2ug+e58f4+Pwrvjc96kxa9+5cX0FwzNbmI9sKOHHNN2bI+55ovLCNE43ytG5eOSyFjgPOytNfGgSlqaeN
llBNsqFuqdVUC1sJSu8Bt5fVpnpgm5b1ip0vgw1BfcBum9xrpy9SVn+cZ6GjcXfyzkV5GRlp9VOdtkYdrYzPY5RLoY5UDz27d/kYwBaoYwtooGSE/ISWJ55jWHY5MCSsHN2XElUiYFk7k6mpxeJ7P5IT7rFw7gIh9cJlzftbk7L+mhqibkFGLJqrNecB/wXYOFtOyqQ6
Tr7Hqe4s+fQeCpHuI+qR22ToHmQLkoMtF6hmIOvMgrZFR5gQD5kOBJr35LOqqcfTy7Xlob4rr+csaRU72tWvfUdtROAgXcKXNYLWMM4oh6ap6K3NRKMVBQ0l4bgPjbqW7vX6Cmj8v1PHwt2kuJ6nJ/0GI13I+Tyf5za2g9n1rqmawE3iLuU9+qNrcmv677dwU3+tP2fL
y6x45dG/TWGyujwuXA84MOIjFVaX+RRiNg2JlBRyYjTVGTnuTt+pwfHyfw0N3ntl0rTDervbdl7fD4vesZYi4SeD0/8gb1SWyEteDjjGAGOeybLMAj7AWmpzaf+/A/7ncFw5Zxc6f6nLt6MHujV+yUS02QGzMg+tc58ddD6Se/7uiaWYRlZrWhtULv90+lDD9K/1uboy
WB053AVkX35/RrW4rDejwAYHRJmYdR5aocm9yqlCqDBgKOVJZAzgNJTikkKhbmJ1+rfMPs4e7f+3mrvPxYuB21O9cN6i91ivB/271xutR48fquZ1JXT+TO+zdSj/6PJNbGKc2N+4v+9HhYl/6W2/bj7DJR9I+8UthwYGZvtctrdmk2f/s3mP78/36uz/q2bzURGvifv7
2qyLqR0xt5hIm/0/P0U1mslMLz11gQHpAxm521JsYP2SvHmB8ougepBePFoIM4oTqyfRJ/UfXGU7pexmJz5PAOR1vq3tGJomwar9s6xth0R991Ije3wFPhvNu2fUdI3s8R7E3o7Yc4ZRDEecbzDgsMuPRjDmMmvdnUEI2LYtMUOoZUhRZeNF2l1m0XWl1E8a32vWrR4l
J7hxfaQ/ov5HquW/aXnS1ru3M+gW8LeYPlNRS8EC0VVYZci52c30vXE5Mz/WnJXE2tpgKuN8rZb7e4vkftxOfw7l2szq9P9JnT7X5Xi86jY+U+vY8uToCqa/nmOL9ZLjcrrW7f9qf8El1t1XqDHqsFu61X91Xpdv4NV4ig7LAUi39wdZsAbBpGmgkmhVLuplwUv2cUK4
F5chWYDKsoqZluSj7Ym7mQU6C8EdxJNg9EqgPMNjJUgv/Y7YpgwvJwFUIyQlDh0e615Y69zy7AE7dtMvYl3fz+DebK/WHAPztZfLi8f2LRT3mp+exyjPIgieWaPtEmi2ZdpHUIlcu74snX17JiEOtyxRAv+mr5oCM9Am9cQ2LAMPKQzK8TT7xahAx8JrYv+FxpSc2Y0s
zAM53QRqADhDgyKj9u44MXZO3ngQ/YBx/j9H9ovhvLHrVo53sc8sVBLAfP10jLxZLxeRe/NnKCKx2LvHqN/vvmT5hPkuJSSpTQ0bry/KXIHIoa1IZHOgB1g9pSgjM5uGpxhA/bT8gPlZuFFgICKCAeBNv/80ioJEgkbCY7aizlsQCjn9csDGcKyMhffvNFcOAWqS7vfN
eCK5pS0W0jcJxTnZzI6L9bNfGUtZJCQ1IkEkGYEmBiLgZVjf9vqWficyyvNv6mqyqY2e9isxsrEuTBRSlyyyndN4ZrBZlXs81joOQsonU9R0PV8sVvTgCicWy3huOpsT7HpWIxKPq5FzrzZLkcsuSfMEPJf3s/gGQxtEcR7M1Zy/PTsy3MFe0Rzt+hCjcO8o79yhwPlt
NrsafF2nG5/r8vBxd476+mhum2knRu+LE12Rtt18O/hxlSTne0xPJ7lYPCDhFXzlQFUktYdIchA8retcMM0ZA1DhAkbvPEBuuFID0CWQpEWEBcs3obXddD3fL+/0uvxqGdH5QuSlQQRBPUIcZQcBzxxTli76y5u6TNU4xz2e3pjJkXJ5xSf4vMX8ce1FHQXIUdFN1iy6
wC7xZAo1nFCdRbHddsQ1vHLWOZqGZhwsy6Cwni0559v/TxXy/lvaPrd28P0j4tSAhAigiXXKUlJL6kJ4REIQYiB5mjfzSG1GTkl5/2Q8syB2EggYcgCKPUmrhz9fcxYIjG8OoZJangdpXkU3nN3RhkgsyC9bOmhJBSKSMSebtYLu3WmqWYXVP2nv4dr/24CRwNC8QsSE
9ACJQXzGiPgJewSjHJTi0iwSIg/3to1GivxkCbb55oGRAcktx2WmymbGmDLLfSFLfJF223iXk6Qof0FkBswGjHtpWHUumHsfhzmK6UD73Hz8hzdL2+tjel2reIzXfenOVcxbnzsdcPpy3v3uBgXEC3AuYF6gb4CWMeggUYIvKnAGAmpFiQmC/hk+yGDc9oNbTD0d0+wy
pRHRclqnYDb/EdELCawSWyCwOnaRpcG4Z9vxNtAq7pTymn9RoNYrapvFdqOVGKGtvx7gfe1aOftXT9T0eMENNBW7klcybHOvEnBUTKq62PX1u1juS+9yA0lH3ZiAetnD7aLbtN09Vzqld17vNu8+6z7q+OorC1L6E6F9tGgscAHjXvw4UhwhOXrh25oKGBYrHSUzTFUV
BVatUpGytQs0nwNTAsftHG93b8b871dv3TkyUnd8bsw91JHWv3n8I99M6p171Sn7Cjb/b+Br73isksy2nL+9dN3x/x4ePbmztpHnYVDl8/HQXv6NN/Y8T6dO1Njhqqvs/PbsjVDfeHeNLqJWZ1n97bJ9veY3kZGfueOq6TyuDpM/2p39aPDgiUQeys8S2ErTBwS2YeSz
hYQJ09I/WkTPHFlB+N6RoQi80Ld7gz489ldk539Lj2+P4/1cvHY8OyLHbkSM9pMJURtNVUWN79FVzukz+TofZW2v0fL3z0s383mNnbmnKIzVwQtuGdcS9NweU7Q0PLs6uThYm1710wyY3vZ3QtiENj9mXDikndrvIZZd5O0OUeTy63aLzg07FIWHGWDV4W82teuwu11T
O6/VL3nMwyrQQ4J1LohEyIIl5lxagEwAJiC+eSCauf2QImBNqXNiCOwB8TMvV1wsxwH7BV3lmXeABKPZGjSqqZ2ymLnXV9XNba0vMb/ynj5PZWG57HNhDU6u8cucMWos4xxf5d3VqlJcD1fGxGDdPV5ET3PKq/K9i9Dt39mWB0dY/k/TynNDxtVj8XBgusvRpzy/QfdY
sTG/iNV2x89hicVwX1C/nvaMVuQkHeF2FVuVu8uekXSDKVaxVBZmFq+WCpfr+JyB8/zp/PnLU0JwPFg4KCeHRfnTBjTX+7AUE7IH+Dej0K87J/mdj/Iy+Kt/wuaivtq39J8Kh8+5+BX0Fce9/ZtAqo6R3xnMht1/Ps8L7P/b/fZigrDK1q1llO328VbEQz4xiKE9FmM0
OHEnu9FtDU4D4In60sOG/dBndvOQ0CCTJ6JATKJmQzEsUuL9ulND+G/LFwqGvn/o7dv5XnBdHm3bF5fWvln5NoztfRdMpE2ovy2zszrmLlDLjKFtU8iln55OeP+iXR942ctE5KpOC/AW3mp5id9Y9gZO/Kf7RpTWbCkHS8PblIYQiX4LgOwilK8WJWi8nNSC2qplVnm0
cgjFgsNg8p1NvDezyH3dcHbbrna7lRWJk4Oo07CfqPA5TnEhareR/AfY3HnHUw6v+s1DVCcdj9h+ihsgfovpXfBzNbV7Z1ENt4NT4Z01Hsnzoh60Rdh8uhoaNNBT7gTlxsM6IU0CpAqmLFLcVKpU1q+oKjspwYJthTmm5G6qlS90dM5yWftunWxEhDWPOyUtnzyKZTay
PIe8VeQ60sX8+3/YWMiHtThIFZNuyVgWRSJ59Y2d3WZFZfdNzOpdYYRczUT5YC7K6CF0AvLcrWcdfOg1H5Ow5IomLR5sIrXE68dG2m2GwkJL1Oc5+Gfg5Sjtnd2o9tc36gO/geqZsMvzoyc1oS2FPwM4KDej2n+h2zxfLaOw1v6C+JeEi3Pee2UWH/lrlon88Cs4vD6z
7yeledI1veXbLgIfYy5wulfaUj1MzdRjNFjy0YET1sHMFcXqerQghHcqGAsCCMv+obrwIXNOhrI2zQZy/3i9xRJ2cx1/M2b/Gdh+tJq29q/WWL3MDwgrJ0nXKdAvcX9d1N00/mCUs69cS0fG9sxJkvmCZ9AMRQS9KDD3lE83gMdL+ZqWf7mmYcE5QIxPUaNHnQgLf/x5
1jdHD64KcWETWxDfQ9QK6hNRDYkO33pQeShCfRVRSJUga7/PVi5G2/jmXvz5TuvC4Q+oMdrZsErSn0F9+EMuF+uvl/kN3okgupjw6l2rIx999/pCG9JsCZ357M8OzunHpzKm+++9co/m4Dd42rrz4+t6M1wVE+hfScvdxfUxLCridlu4HOrkSYiSHC1iEe+v951sfRyk
QsPSfyO5T84J13Z6av7zO9iT3niw1ABGl5bH3YSE6lT5r0CEd5UFQ2VVulXSAH1sURgYIgqojZU9QBOXFaM0sWQTvbQWpIWSqcAaiQzvLjTZQLhaml1E6XAIlnJtiwFxIOSuwXK51SlUAM+20Ab0BdF+iu8HQg6kATuqgFDlKqFUKWqhosNJUs441W1TLZTI7+wFZs7R
udrp97+DsusOuvJBBbJCtY7wcmoOnnR5s/BD0hgBwxzJpAT6A8a1XVrs/y1g757DAgB8Wcnz58hf2YVEFZ5NRhMTHzvYuvL23HZbtcykaM0NkFlLfJLrkXSiZYVAQ+P9HhRvuPms7R6P3+l0r8LqXy323IpR99iTdxc/QLLKUopSf4vjlLksxLFP+34Wg3PKJY3nilLO
+ZCHSeQ+SpnpKWWUppiYnOqUpTmr72kKRNQxL1l68mJryw03pWuUxH6TSU7FTiGR/A/gPx6JkGaKGsWGqL2ewRePD2TBezRQ9sMYXsqUpH9tlimC9vbE5RrGNmNeNR+VgmYpNJTSXMiZ6xSizYuyabSY1M5Mb+65cyFi9gvSyj+VjFwoYmmYMQwZrYr2VPiqZRojIssz
FLMTUb6wL1zGvXBYysxnu5XjG+cMYzRYucAwSTBrmg1W7Ptsoxte5p4y5c0mtNEYPpeyUlyVvEGHBT2RrbJpByjXhPOS0dYXdj6mXe03ITI44e2uDNkwSwQ8OwEpdYlb67X3LXvHC88Gs7GN92xpr/hPBS0eIdoy/pVHfNP+Bqy/aMEnxLuagGhx8dOGFJM9pD5Ke/39
9xqLOHQbyfhlCysG4wqKoLE6QaJPVWHXcDd7m1iC2sxD/gnjLM2QlMdRbE05iTth/YQgIugaYFxgCdHxaW3ijEVnXFB033THaju46lTpyx1bXiHdYRub4UF8JZycr36NpPkoMzNdgQ7j9QhObEIb1kqFQ0yPLIGWiTRNJbiM/UrLdYA/6qumUxpvSPO9HnbIKK++CtV5
KgxVjWMJ1jUdV3PSYjxXpPbUlN2x5EgIkHBZ52eFtzzrA3T23YcGIZtEjoiLNKvdEUGN+wujT/Q9A2Ed2pU0z+ZkZSeWGLhQl811cZHaa9ci/JNB6G0a+IFmFBtVUMkoYhW2o1alnDlo2nS9Vp9NvrsT0qHHafUrmyUjzyg1tJZSLjuVHiqLhSlImJSxSc96xyey1rgX
Ufs3D6imrUc7XUlJ92ocxR8unINI3Hge5zv0fiX6WwUAxWirjORw3ZvgNPARkSZCEMqAjBeP0NRBO6VGvPWQGRdKSL2aHkDMUhkY6PJGNI855IZD9wegrdlwvxPyGXZXzJ3Mv5ZYC4i4JEQ2Yfbm9yBoWuE8Z9vQZgOiR+n57Cg0W+mP7sSlpoulzP56qlMyDDl9jUIq
EKSxTYsStWrJ0vNuu75jlWHYA+qfNwrz6JWeVQusVdpZctXgp6dyZorRZBC9xfWOD3oooz1XE0pIEP089SUzmDieQNRGovECJVYXfwlLzHNhVglQ+0oYQlCdr+JHte4iXpq6pWu8ETK/eV3JwlJ1Qbs8kNEbNa/3faa7zYu4w58nNvQMhIqmysfFO3QpxvGP2/7fwRE5
YCgdIEUJMx57u9C8n7A+OgONS+LniNHB6AQ2AKNLYIbkp5lmsqp6A+/3wkoY2HOxXUPX9CNldLprcEoY/XBriRERZLZXaV+3+2gdXQkWXCMJUpAKkYGIHLsUtAiTdecQxlNTkMYgY/uH0hXZeDzYc4WDgQgmWuW4W9+N/2kNmQW5JndIcZvJyjCHClmDEfgG7ZEGIvg8
iTydAww2FiPIKHYUPHDyfhJUu8PO5wO081sohlkMsSzr2eT0Psf9XlpPKeYyVEJbaeacrbS0nuE38U5U8lEp/I8wT77gZ/mjiHfJzLIEiAWgsPDXypGU1okXkreQdt5a/SacgPlCqszRNHcYwfL3Esil80dO9MhlXiX/gPhMK2MPEEcOAxCogKY5IR88wCGQ+4ofPLLK
UucGpkTarkq9/rsk+MmCfIUyJx1ycV2hQ/gFD5LheLRIZf6KDGGvXCCvGgCb9J2jJwtSSISPAuz9n1Ewsacx+qOzU0WHmXXGy0dQ6pVCG6X8iaMiE4BIjQ+64REh8Pow/k8QxAj82esBIOQ4iKAYTTHKGVltIyiw3IXwM1V74gusHpH83IUwIRJ25xL+IRmz3FsG8UBC
85wck3R9R+c+96ci49TYOlbofYMR844A2qpmlSqqpVFFahrmod2J9o/pfae+P3nRJ9bbf5eNt01DRfK0ll78DiEs8+1vBsBcp3anzin3lFvXvWsQuXsShiLsmBmsHvDq1jn3FNJuHuu0j63L26avzDxG/ei8A0Oy/31Rome8n4vsRz7ExN5s9ApdPK24hTMcQYO0ObHV
PJcoYkcidA0DNJ8VzLWOGOBcg/2VOSK7zmIENOXYqBpMCa8Iooj+rK3lqO8fI3RzDtCpMjkGZ5LltIMk6Mb/FcDvmrYQwif2loJ28t3zfCiq3NWznat0qNf1pri1nM3WGsDrepe/hTQZSevjHWsSTtyXPzqeBzJxC3ck6f0HDE8FosCdO9o4N8Z+HExE0yfw2Tsjqn6b
Jwz7KeP61uCmsMBcsj1wweCNByFEwXvwh0C05+YWyO4OXdJmLr1Kge+TCyRhjllodzK97PjyvP+t7jh30H/XD9g96Q/8Pn0fxn9funpCqYK03Jx82Eo2NOFL1/nMii/xym3mqcjvQ/LwZR5/8vTYx6exH6+MRDtPO80IcwUaFDGMYULEonVJCqr2bt1Ey+HiRevv08y8
jobGbmPg/5KOIPOOVLyLzeQEkiQwJJzCLznOUuOdXHOmIvS7IY1F5iS5ZMKpK0FAVD5aoF4sF4KBcyuDbseSYuueLssoQlWCermIwmkc4hg2PJtLwYI5x0iLrcb4Zmy1EOHkUaNbvWJ3z7uvz+3i5epzPKiEyCSzbIjoaEly9WQbW48++DkjJ0J0LyCOAPDM1BFTjDZf
Y9PYLPdoOd1vtDBP9A7gYvCFUTYNPB7B5zmXy4Oc+kGa0VdXV2RY8/8wD+/oW7qvP0floefp8XoX0Ob4ByzoRwJcomS4uOVLvEFCnGBsEinAfqO3oGj+5fvK7ZjTHGFeppY0hyYtdgNwinS3tYF7yIcFyjor2CNKFusTE8CJeUOE4HAsuBb29vbzVv/O32GAkHdjW+nl
dVj7y1jV8CMl1QsgcJ4YSwYgjgYFAoKhpgS9vXKDa85oPXvkfwle9HZusEZqg5/DqbCBxXb5qNynjoX7jtTG/KifEGfzcl5s8fR3prfrB7fOdj2dThoa0M8RVofqFcJU3H2rPzWAz7WjiqOjs1HR0dHlMLR0dHR4+gslHRuLnGRF+tpbMU4835d1cBKhkltL7YuJscQB
wNXNbz9Q7GkHgGFiD0XbrWhDrWmGhVgRWQxTnWfKlpZtzpWSlTgJqlpM7S6HMzjtO9IQ0aKDZ7L4BcSgrKgqDVCg9PUcQofpLZl4yNv/cI/iBncVqsJoDl4AkMZTA0wX8CUIjJXmoFWR9WO0ImN7y915A3qwYISYDd3iNdF4gDWvSkFwXryscd8j/w8tDZOToZYGkyzR
lI0KFasRbUoHGfK1mCWeLc0yck1jKKEAU8CIwgdPNjAfyaQk4n9SFMeTufJykG5jBqZBzvyuPFMALQ0cROT9FUllMOzg3z+jy36wGnF+q88cLyzl+6u3q9/O75Z6lSWfzpYvUjcqYKRQoNChZiCgoan8Zc59pvx2UpyB9MkU5j7jy5aOoB2HrnD7xI8jdFxNyQbwG/9V
2vX/UGzE6azEpdCato/IeYqHQI9wM4SIuTmgocb2n8lsf3DR3uKHOVverjQfxZuTDS4c20JjMCI4KMUd/gu7G8qdyhzvr1OMghjOcoKFslKfvi+EGoaZaI997WIKRI7JyTlTId/2d2y/THVmPJ52eePs4Hvnj807YPWCMIzRKmMT4yoCXwRL1qivTJ6cvETse3KM6Tim
o1tKf7j6zaUcwE6wmujmocUNKhRoOyN01IIbTLelfdxATctVabrmIUdqKoKR4fWMGHDDynOt3TzaDo45SPp3yuWEwRBKSEllxmJ+LCUCUiDJuwJmTQgipDuxjpfxzd7iUmOHc/jYE5JfoMXve2kge6VFYVM94B3LEqzXRwvTXNSByR4Wo1ImU4oMnwe67Z5G3OvBthe3
+HI5MBlBwk/mee8njbtzLHpNj6S/MdrdevfJ6W3uPA6+q7feph9zcHtNokejidXaj9qVIpTBoIRWfP4k1x6lzo/TDaPzcbbfDNZznjA7bDevw7gQ1kOQn3uD4p3nrfXfl+xN/zfMnNNNVsrVw61rVDC1BLFvGrgtXKvRjLUoooYsk+MwptcoRrFyvLkMGepZTIx7i3Rv
oaGbTYcngsjpSv83lKgLJkU9LQWx+fajxAeNJ3+67h/N+y5zH6ed78Cwe6H5FVDsUnjqoPwh8Mk+VSKtItMWM15zMIf8N0fkzixnsJ1vIgT15E3RP9E3h75iljImYzJ9dmktOB+HlIYcJj43Y9Z0B/0YL3NTY8gcJ/z8Q8pwVpa22lr/lN2M5nK4+llfl4266IqKhkmD
EVbzfd9Ivhb4Ae55076ipoyjVv1S+02CZqu6GFMoSccMOe/Fw2urvZ/PFG2mILIdHvk8mmFTWnrnsJ0MZV/FMok2l3JsNNLmGjPy33fNqbueCFdgYHuHOXo1VMW5ziVd0uSr0/FcvqMaQZko4a2lSLjpt1Xp98fY5GSNbjaTgm8DkOxLE+f9r9Wb/JKlA1DBgc9Qx0mK
MMVwIb3PIbh6Bx7B3CEdMMYMYxz4F3aGwfftLS0ti67k70Zvs/8me1RwrhtC4C5CDPjzphIlCPBJIyXKluR+cxLuhXfIGgM0Q6VjZk/gOgkuA5tuDzT3LgjZ5iPP4eum8S9ZwaqpSqzZafwM9OGg6qNYhajpDWNpUo6l/+jOCs2mf6+yWwKTEZWAIAIzLHUuX9F57pQ/
wPoe9kfx/voujip+6T1caL68n0aY6BcL72GadV/jQtI0oqiijGQlK44H0MG+swT1cz/YrnylPJvJ1TIIwRIpMUfKZj7PjIASbOsVCX6xS2yIS5Ujnc7DHPMRG4j2N5SB+pMUZhPwfb6iKiKiouj3gb5ocEoOPEgQr75+hySwr5U9j8CmLLDXNADqipsZFgnTVAC7qIeH
rEnLvLzq2RVd/Oo9fZ6gqm+yyyq4iWWKpY5EhIjDiLlMGsIyRptqbx8J/UDYj5Z/9lb/ZE3WvWLVB4THu941YInA/Ge3nt5mzNnmpY5lestayeb4Z/Yc4TT3XnOTPwXsjuNyWQ5NipW/PuIIqM/2gKSH/u3SlMpYTJfghmUmEui9RlKsUQBxBZULZYCiEvwio2j0Rf4w
/1eaa5zy8qOhVbsY/M3gEzvYe6yTyjt492EgYv2e30mobJhOzoqeaQ4T64b/A629fyYbHtqyEZg7hK6/Q0MW0JIp7uFRPc0Zayu+3X63oHbOx2FVkTKo5P5vuML8ULBsHpBkqSgZWFHqqFYwDtAz7BAw7QIgOUoToNbFr4xAph3/utbdYUvtvi2gTp/yNNvF41ex7qvC
/lxsdpm7ZmW7L+R9jL/OaS1/Dz/2PZ8SFZrrN78H515ux81J6nz6M9/oYqFw8BKH9v/jttpAQapiVN1FXDyHCWj1uWkBOGod1QAvCp57m/VDigwfn4i8Nwa9KNZPTyzaRHyfNW89N1Ac07AuH6I8hM45q+d2vpnuECP2SHcD7NPquVhPKdHXfeg3vAth32M0IXatRVqw
bLeqEwpopWC+YnEN83DpdY9+s3avfAiW9T45tbGlREwKomTgvFjiQQ7f+Yg43bY6Ysmco0xH2+XIXhna3E3KjmeD2cT6rNDkFwfb9t4WP/Ue+hLsjDGoGXZ/qbXReIoAdWrgG3n2XQ3/9GZYTaX3mqIwYV+wuHD5hun+nYDgnwha6/4WzXe1SNGqNQCRAhs5WvGft6af
EOku0T56ey+o2KShA+8cIvIdmx2DsMOZhvojsXKtLeSoPy6+veMdDhLDMQ+C8KANaUbpKH9L9XKXdOZ9ClDDKGc36l37ol80SIJbreS1RtQSS73+6w8oKQt2mgLozlpmGQt1WoFtYmDhC+2rEFP974pycqU3p1+Sye9MzCbgpBp3w/7FHrbpJlENhPTMousOw2XvWA5J
sC7KhfGxgsXt+OvyBVDBDkaiEO0dQOTZIDmRl7Bf6CpEN2kMpKan0XMbPEXr+GJCLhbCYE1CzyY6YHrSi8cwIb7tjRqNrf5+X4PmviRIKkveTMRpLlK5BoBFRC6B9ZYCbPLAeeFmj0QIbt+3JiK/aGziorXud9Zth5qpr14Tlirs2ZNth3qMzdzz0+Afdg7YxJ5yAJ1Z
T0ebZdVsC3JiIjXxX89g612nDsZpzuNtuzrfv0GKG9WghSSeoQA31j8LPew7PiCMitvsGdc/fcc5jRQxEjscd2DTSkVHvHJOVcUchF3MoEQjfAiIHF+a0CiYKzo8ssOYtckr8JF+bBA6iNAf+1oOrEh9Rq3l5eJpTwaWY7ZPGRuvZH/jkmYmiNZii7t9FTvuCKStBHBW
mGcNJjU1Esb/NCZalPBOPiAXHcnm7dCWGvlkRMaUQPSSvpBR8OiFKsmz0OZcsv5jG+BLgOt9h7jOR3qk6byLJ4U1f3G1zIfYmjwn67hPpvqn80Kz90VGGbOfzS86KSAQPP1TLD/us+biB7uQ65Kcomx88gVVVUBRPdFv7LD5mHdjqmKL6SpvB4Sb+NUGs3AX9CF6M4VI
hXRGYM3jRD4GxdQ8e5DsDEsmv4y8yFpMTf3MMTPPuKX6zU3yFLMV5k/XfF55hA6HW10jJwu6uu0PWPzb/5O1taQ7aH+wftQolUoie6KIhHKnxEe56RfstO2g+3bF7Ak3DcKdAw29MWZLPbVN4J3TklFN8l0/GOhTFPPPQvRp9WaZMNzfNvd4jY2hySpHF1/8KWvi9OQT
1WeJA8mOThzvtcUO+cs7nX2wYvP+yJpC0Q6I3WNHeUTx3TbRDyx6dVVSVX0uEtOsrjsSevm1c2eJfI6F+ApvCYnX8I5I4edsTqpecNOLQ9s3CZyTEg5/g73yfTNn5ZLNz/TjohIgwwiXgS7l3GXXcMxil3VJtjhppQMx0pY9vfbPibUlTrizqEnEtlSNnUM4nkZEayVe
Qwc69WcqnEJo7VPptPc8zPW6ac2qVlEsJMjBMphx3JPv0jXcl83oLFv3SSq2kQe1EVT2FleAwrtgMDcio4qjj6RANecdiENqV4byBIdrGiSFnRpdn4WWxLtVkcYuhc9MieOzVyaKNb10OLlJRKT3/1vdsh82yx+QuQVps9qrEAv+wUceGFuLYjB9ZgvC2gsmxBNIReba
hL2hA9F865n1iEcEuSLgIv4j4kyNG6OuWGBNGewcR8yk/1vuH+uyNoRkf3djp0CSbVjK3NBT4yNREcoEW6SIgvpBsSRJO7HOpHAnCPwmN8s67pzyPiWQGg53otSbrYc565NqSJIEkJAhHmiACvnN/eyH1+x4exf4Lioir+Z+Dp4Fi4iIhxDJU0yTKyiGSJlp1QQqSMS5
1Bv9F3hjdwHn6dA/Xy/AgNIytZvmgYDOLa7/Mc7Rwb+VXgtih2ifFZHHMBWL5Wh1tlM9hB94ebNb3O5aCdCswxiT3y2gfm61uJjgjWvyDgKHtDfrR6Em7skMquB0Oi6vZVYu6PJkyfAqi1DO9M4nqvfRa96V9cyOrO4YeNPmUoKakI48r5ggI1/kiGEKl/Pm0j+YFYHl
sRpDS9NpDtqXMc7gyQeqTzw2Q1fYYBtCJKDouhGTFEeavlyWO5qcnV4WZaIFiEYmaAInOld+UP09p8GwuxccVRHjci+C/DGeaus6KIfk48hAj8sE2EesEbIZ3S8OIuzPE1Gm/T4ey1XanjnfmKzGDNkvAmOmDjRJC2INvhRsa8wUPX6fMCuXhwRjMiznKcECBwxVx5um
Wo/AP4S2vJAJ/LUxvNx8zb+JcvAIlMjo9Pr6jICNXpmgG8iYApKWg/QmJR7EgD0FFUVRVFmpRSKKKKKKKKKKKKKKKO+lpA8bPPzciXMjJFFFFFFFlACUiiijx2aELzqvmr6fLn6ta6XbJmYX6Cqa7CsatYwQUWKKKKO477MNOuWtliVqRq998uUFmCmLyej4ecc8KZGX
Oo6UuWYT0qWYXtlGG/MTAgWBZ7+UY9WTNLFkUUc5nHhXL5UUnyUpHOZp1hqxZPeTZH4VBnLmczoooooooo9poLE8RC9pSf10FkUUmzErNCiqwsaol0FFKDXhQMS14FFUSikUUUUUUcJYPVCbbxSipMTSCJbfEEODUVwdLhvPn0Kk0OoIM7CklZUaQ4m/LAgMPEPPEtZk
cmxrhfvlFyqikEqULHGzSmULzZsc1BDKL1ovIkGes16zzw9mNKUAGhZHoNg7z2LG4Q9ItSKicj3Plnh4X/W/V5sq0+eDJW9ZZxG/u4Q1QJpyBAyBQW/rZOJ8yyDMGKHmRzUkYSUnDk4iHOR0goCDBOrTfVnNusFwxXJnQrJXNcRoULLwh0LYmkj1VDiRrAsOggdUSiUn
7q6aEwRvHPT+ZDwkvRfsIz3Uzz4zJiZVO1ZXRvM0mKhrTMSiYxqzYTWNOaMMBljQRu2RkCoSl4zUMFjNlL0kXKXKRspExMT4eAMQkASh1xXNgjwjaaTbinaE6wch3LVBWhsDcKRgR9cwhrSa6zf46naSzpx6b9ffmSZExMbfo1ikWfQ9z7fYe18p432tAdGXOaSpzpPu
isFPWUHSM6b3B8l5GF+v+tgamn+Pr/Rf3cnpZtV6A6zkkTMbw2pk6f1H8mtx5cvIJvw2M3+WhC04EbsJ5DHIYDyw4ANyoXDYxntaj5Y3SpTQl0KGemjHKRfMa5gqs9Z5gTBnIoonJykzI0EwTUMTOnZ5WkXDNSwXEUDw3zNzZ5e+NT/MI0uF8+eMsq4psjOxKdOLCECL
MIRA00xqy5btuu2gyKJlo/ob0l6nyD7nX+TlYMRoBSzIpRs1yXLGkLJJ+cpe84tiTWprDBpd4ViYiz7vOXzhM8mZoLRYsODdI31SlxgjMZ7gjG6Tsi9KhjxytSZGsXTndiz2ezme4djzJprNcqrWUxMS4XNtkukkL2e/W4fVZTYRybfS4xqGYqW7Osb/X3TsfgHK83n9
B7wzDkFzfGyu8+pcpe6dQIIIUPGIM8ZBniI9YOSFiGERFROFDKZyhGRL7WZb7/K/5dlstkPRbjQZzRfVezvZ5orJBpKUKawLE6hcLhYYMrtN1rBexoUprk+az+w8Cybw3liFDBsWDZDgwqGpCoWJGsx2JVMDBMPRr4XF6cqSjytTWShL5UiYLJ3M4ZrJg8FU/Vl7rWNt
2BZlUDf6XTLG/rTQRnTMKgqWl0nFcNdIxyaLaCpnQVJKHFNfrzQVVTAUtM2YLoxIYlQyJnSFwzfzGcm9jIzWoZLqXI+MtZVRcN3YLkUUlSkqUKaU+Z52aI160mgplakutdqPpmfM6TOlTOk69KGkh+aQoZg9ALGixqrVHILzdmwme1E+VMaNmbEcAlPHhoJQnI3BfO1K
ixgoZozWqzCWm7pqKTdk8ZwCqOea8+nSxYs6odQwIfA7W52Rm/E+e6BgEO4NiATDqw61fDlwEJl/u9heUPi5p1np9fxnqtPxca0ps5s2sUpSUUz5EsulkVFla1v20gj7O4RhMTIRZLmCksYcRUcApDvhNtMMoxJY0gTOFQKDYWsRY5+FvZ4u5moUIOHRh6Q10q1bT8U7
O8W49YP2DguWeZ3vB0TmMszkvkm02l6c5emf9J68uzTUzIbRN+nNRyLical71WVFplnMGSF7xcCnOzjbb8f2g44C4pkKLzdabBHMk9CRbyG4HAbQJbsuy8xjaO1N2tOdm/5xgN6KUrfSWcJUWOSXoummqchJLhc86xPDLxhPs1CyQxSydO/pOvcup1zFlEEVoDHvZ8HS
d+wXFJTqBN0EW2e24wHk03Kc/emDijFyoMRMrMPVDb9Th8Sed+C7LZ93yvkE67wmf9LNiOMdUHjpQwSJShULx0I8qPXEvHGKn01JLMDjDYL2UOgVMGZBG4YYHomf8pzk6uFIKnLjKuip55rZmRNJpOdkYjkU6ZS5rlRFXoqWJgBSLUJBgwVIQCBFWDSlSNo3uz0OKawZ
GY569iZJw6Z8hrVKTrZnzrExotJAZENphM5z2iFpLFIhP2fKopTDQTwG25qiM5B5Pi0MkXAzpkjxG3Ori+nuIIIA9R4pWE4mvVs1jsvRr0VqgbwWo4V64fhQHLjYuAoHvdZd2YnnrmIC9T4jiIpRPoQKIGIIY6xEhxLY9sojcl4N4RtWkAJis1OdkE4OHmzBEH7GiD8q
QM6YzVSdUWXbC8IY8xIKyf1EzNzc3N6mfLTN6/a+E1hNmkK+BNmDLDE2YEY1tUQmZcjLmB5rIgJ9uqWJEAUcExScfHu4b3GE6iY0qKb84eVYwE5NRIss54XEWl0Ki9KPbS9LlykkpTJKlpEmEwGRyCY5C8ZYLNvimvORWL4imDoE62RqPWUXxdN51oymGQa1rVKpMkLk
6j4gUSiA4AzGVfwPR2pA7E0BpD+Py6GdMbwP9TQZSvfQgiGKoYxlbS0sLS0sxS0umy76FJ2Or+BgCaCdIMYKIoBeyFeyWnq6nJsxJeZH5Byp3NzOWmEZzRmzALBESWyrhQ26LyXzg+JTrma3LikxoymY/JnyLdg+EfrO14r1fH+X+Tzf8W++By+Y1TZFGkqJSjYrLFUq
lVase222222222223P8L33h52erQaK5IUKJSh0Ps7D8T76x/u4WbS6T0HBsyXBgibW6YgpZM6XBShYsvlXxgLwwkklL1y1pFTlci5jlKmAtIopCdZiPesTwsrNbypSj2TK512RuKxjzIWYt6VgVFBI3diEaWgYDdgbSHvEoZyXNRRSlMBfjY0ce/v7Dluz/d6569C5YU
Htg6KHzFaamZmZmZmZmZm9XU+D+dWAkkP4owRS5AwCZDAm8P2HpLL7nqQLkWEoUiGlRUpQqTIl1AI5ovsGoxNRelQqb0KLkKTGs5lwpF9AZRUgvG7Kj0szy9JdchQ1hfmkyGujK4ibViGAxy9MsylCYzBGCpGQj1ELpURZMB2CQ5olyNNimNmtSiqVUbdrSaiUZxnTAx
s6Zepeu+57L37v5x6h+92to2cL3pkTP3WylvJbE0F9P8QpEjUkCoorTT3haCgj6CgoKCgzus9LQ8HwIXPqCjAUiqbAHE7TAsfqUdCY+rfsPEJE/tfVrnHe6gbibhNuj0UpLOLWVPBepJJ+JuFUi+UMUof7PMtWM2QkwaCpmo903LAY5eLLc3OYIKQpQVDbKFLmBPMpyr
McKqrZ8uYMWwNBe0plFJzEXNeqXOXVVEna95+rrnuO4eyfc8j+N/vongeb/UKX9g2ZZd7T/fvYpC50/vU9PK09PT09Pf//PstbzI1wz1Mjf+AN7MU+c8e5cct23RdWMXlMRnQ5ne7Pxg38JChHOxbjv3L4Yxg50UGy6b9rn+He38mpScSrlFlo5RZZZZZZT1i5ZZRgWK
lql1GraGdZteJxOJxOJxOJuPZ8pqm+PA1yBtBC5GtLLJKcD5grvF7E87ih8tUvkmS0tMnqrkOI3mga4C+gZxdONJ1A5BNICYmpsnOsKmVxGKVF+YOcTZubiyphIc2nsYjTa6ZsmlNM3yZ8yy5OY0ZpUq9BeTOj2U00hdRLic/HoaMSXyZgqUxajWKac0TXJqeeNQayI8
uzFprBrCaM0JPWKFUiXyZkpaJVDSUkk164WHYyh2fpMTBWVLEXeH6x9X+NwVvRMrV6A4DqOf6rTbQlSOTwhwT9obEaIkhxgo0KMUaZPx8dPz9501620B1xX4ROAUTsFF1ew9Rd/acvbBGoMBqrh7VqizNXtqLl7G4gYL3eUmZu4xFxiThE9oxL0kbuYnrf72HlnH75NO
F9pXaWmtnQy/Ofta2NavxzkE4w0o5WG3EFLgVKhspLkwNL5kE4aGwYnmSi9rZxiHrnHXTOZZoMijYllRVJSL52mExeXNZF01De+FZIayYksM20SY0vRoi+Zl8pcLJ7FJULlS4qabOXLg84/U+W1BsWI+IzMi9Y8Io9v9yx4NT9vtyyeNwdp4fRPdLp5qp53uixNRSfNo
7f5+8m63bvnCMblrza76yNm4R5Vs2DDG2jC/FjvxtCPWe99lr868AHv0fWCYduJi8TxvHXu2+ppQIaDvIAdV6O08XQ1W7tiSjJprLmwYliixe16n4se75ti9vi5hMB9vCNzaoL/hzFgi1AqBEfv/bRdAh0HFwFtUcgdzJfL8Nxm4oakwVDIht7rfRwlphKa5GGYl8pHA
AZBiSUTtQ2RYnBMlkIaYm4OfmBJYHASTKTgxyM266GhUrEhmy1TRkY0TORJvlSTdhoJJMshv7UnFJM5iKS5Za1ISlSLBmjJHWsrlM5IbKjQmNlmWZc1DNYjW2pJ4kQQjIyIwgwNmS5kItAdNRJyaGEnttMZjQSG93DSNp/b7vYtz2/k7vzbufsvNsP0Hyj1g4z6FjXno
HNv1D990Jd9gjVSfNdHn85wNaNFuDXtqg05lgtaEb0T+ML4ssjphmfoZFq9v8E7o3A36jmwSdQfRSjAczE6JekQl2NjHJHJ/mpzB5s9GKOMm/zfmVxjHNkzXqKYqxGc3fEwZFJQ5M0vLzUbEhmpkmNOUuXKKKKAKDikhLYiXBjwLSfGLFnG7pSq0vdgIUUUgkpblxoKL
TrMndZtvcKsp4Vq1YAkme4UMgSYOB/gx+ORNk0IjowgYYCSJNRXANgRcyA5H0gRudlMAR33h/ce6/X/CVmRCnNWRkB78Ck6OHy56+5EfaiF3CloXvP7/ieRgqTQSsnj5IjJIgxoEdJtYIQuAg+xP4LmqGVCvOuKj9MFoYmxoQ37gmVvaFkeh/hQisGeecJAYiSPiYuu+
UzgkEJzhRNIigRx0vreaK2IcvpKHh/p6cKHvVU4ROvfs6FMZMfwxLebvJYikQUo0MGmDJXT36l9A07spB5+jwS+lmB1A58XtJlYhZe4KmCUQ7pPRcxka1SmRKMhakmuTwbwuKDM9TCUBafwB4m5PraxteV1T2AlubIC7kCEBTWC8Y7sOiwXFsPN7Aw26y/ACXptdrlw3
AoXY0lmSQ//EVsCgayaJXBzUz/KwysIWh9W54pxwS9Z1hDqDOUij/7mMcdetEBmEiNrkj2P2DglS1T1+OgxIJs+0pAHVbtR1EBc3p0dnlhpdhwQXOBQOohU4nl4ETfoLGkQ/oC6OfPDo9LHoDB8qS8uPKG57AhhmmyFDHR/tOXWII8uJgZ+RH+gxHVJwPO5yabZ/O+QB
VKmJuLwzlUz0srLSYWQP2ULweCDZnHg80VDC9bIn+bCw0YzFjsTDBfLgFxgydS/LfUCHS8D6oy5I9pHDwUYOJpO0S4SWgdvvbavrFtQFq9xVg/fBLQ5pRUTtsVX5o661dYVLTjB1Glc8yEexvTtjp3jW8U7ZoWYJ09g42mCiXwCkrQSKBobvXRL+4uIfGMMiu1qItpfK
ZWC/83x+HgOA9KM4+1QFDWNHAwrcFqxwxJTFpqqKKqho1KLQYK2ShRVEQMEpP0GUn3PzfU9/3+Xh4h1NZGziknZ3cxfLUaPf6DeVchqit/3S9NwiwUael47g3iZe8zDd8XycsFeLQxuuGaEeeGBf1Cb3JlLYEEVZYxUZ59QF4Yhj8APwcEYh0v6lh4sTsPwP4biXp1lG
PeOk421XNx29uJ37IUceS4lyXJQXEpLKSU9msmuKU4CyzZLL1GOgxUXthSylMFPmKWb1++9j6fqnyNgbS4YFUrzmeolviH/FhyGw0qEKWpJYVndnl0/4DvB6Tlgqkmj8nZlBGeZ1lAIFgiUSVWGLcgtEGXa+Bx9hSDFTMogYqGDNGEsETbGgk0m4TWaMrFUAnKqI0Zk6
9sWnW9jia2O02C8LBVMUyq0lrUzZKuN1fXuvr7RqRhCiFncBJWIr/vXeBPbSLkpsihFpPiJO6OCnpTqhI6NLWMv6h5qtpm9GwRmUrm51XlXkGp7gPsa8XpjNoHZHHmODPGxGHQ8ILRpPt9xhdGmJXgoYouzMTwGJuyYkKRES4lGrBQaQo1m8+U0IK37CqiI2UaGqoYjQ
tWLFvuT6iZzQGpaW/wXz/n443+1A0YhgfidAP12StOEEaVCjJOdd+CiIX7ixQY4dFQUjAzZefWAkT7AREN3Ja/1beQd69PzkbCCEIOxU2G3XjiqmoBnBn9oNxmLfQV3DwQxwXELpa1lBpeIndF/MSHF/GQS2sqW1QY3qPi9DyLPpgqSEHHtAiOP73nJ5fr+ePbiNfZCO
r5WDOb1AgnT+ybK249a72g5y6XZQpzdF/Xj0/Te8ocB60QxR3IwhNQ2Nf32oZj6P+zN3CB787H6eY2Ps6MpJvElJp40GEoRUOWSXTnRwwE6T3BjfCkX5LaM9yId2CE4zIH5MNn8OwEr0ySbrASoSySi9wtBa1MNBcGGHoy2SXqgpCe7mEqGsw8/oAz2MkiCRKUB0rq5s
uQyBEK51Vb3sCH3vehy/kNSTwMkGMBqDKdVjJPTBBG77/aesPiX6nu8cgJydFxS5UbYIiEUiohMLGU0kjQY8GVhbh+qBnKjyl4Urb8qiAWTbKTqKhnnNT48C3cDFhd3Zbi+w+phez7LKTSVP5eH/Q8G/T8Wy0qSPpvMO9/B9RFf/c3HUV3ptdXSkllCWQMp+8fwICb8I
wraVP72PBOYN984gfLW+fcpAxQZ+1z+qO7DzcXdYb7R5B6G/1lrp8TiMzfFoQmJgdGQHHDIpFIsAUBQ9f4YTXLkkuyRZIpIsG0eD5v4S8wqqkeU/DaLpUD71WpHd8k6L9F8H4R3lm6td2MBhOJWyzeETgnBCEcU10CXAwYrtAcBvcuZefHvd6RFnr4wc8UGXuwjRaICi
F6EIY/SFGEDzN6cpv67dUsZ6C/0ALTm0YYOYuFNoSjO7a+bLbuJM8oIBqgr6v141pzD3loxI0+ONKD4axYxu5NJjFL4wYJgF26lCgdksybh/tLvZ7g57T9IvDhqiXHYREi4RVRRQ2rmHmPjf+i3MO51K9oY8tYKGX4v8lgNRPuh2v3/GLmffUtdvb4/47Pl8MWDdn86y
adlpa7hbmwKOWrOrP1tnEPDx+dVB8GvAzZCiiqHYunlGoeh3joP+Pbluq+D3Zwv+RxQrjZa9k9gawuklyz3WBWwYdvVbMYnMTF2t/9dYNWGQ8o5SdDlnncH8/g84vncF/8A/4c7las1Be7/JkshV7Pg+8xl8rl5+Cb0m8tsZSr9+aOA97EOuOYoGzi5mO6BinVT95FN/
E+TDgQA8SsBiGPxrARDSxLBEOoqBoQVKFURK9aaiiSznNfnj1YouZGGlKi5v5yiWCgL9N6zCKBNGOf/wQIh5pWGRiPXiZ9uxxh84Wk2UZB26mmr9pTxXCwNHXDa4AgJO1+yzrwNEk+JsCvq+9sFBGoSiahmFgdoyTQmvVKb6xl0FMjhTOXRccvrZyXq4N6O6RdmdnxRv
GKcnGjMznYkpxdI04aZ8j6O39SrL+rtOyEFOrXCVsPO6JBdzP+IL85HIzX8BUrOquDOykvc7s1/03QnPyXVNLI2XYlEWU070E3lTfmyl/Pv64+pzyyoofA4ET8LM3G9UpUrcU2HWlwzJLl81xJFeOmx2N+s3LJzEBOemNDCdsJwHRtTjYa4tlco7RHyCQREBE7cqQ+Ht
0HHI1HDGrXd4inOwVVmuQ2N1JwjzMsztLDPhCEIxe8zBfCSQd3fYKCrVG3h+UPqMtbIF71hvS9AyW3Vhimkyzr+WqIM7AZ0tXdN80+W5O7g+PWcIDbn58hKcR6Qhjon5DNZTn6rDbjjEK0QhnI/jQm2aDfVSw6sgtfV6qi0/IKAux0TyC9c6oSljUlGTvDosZeBiQa+4
DYaEaqrUrg6PwJfGGysBa1gvDtyCgqJWDIY40FRxenAVehhixu17VZlWVwfdCE/QRc2s9l3CzF9Cwa46wzNA4sWsDLXd4Xabu95QMVVDIawgnGINgakzMWuao59vWFfqj6hhrzPhTECEvsnrdjfQzw4+pvfdK5Wsdg0foNCc4d7JjEblHYhs0flclrOkeng7mWGGKI40
jj+LiGsDjeN2BftIA0rsD1Bm8BDwc/A7cL+VE5I7sK6ltmRDNEmcvlPoOVmUer8rsx5V4ua92jGEaQwOvw/O756Yh6xBqSQsHcL8SA13Ej+7Em2m+jmNSN4/wsXq5PQtTS0cxNuBJXsx3srLWEcf99EDkvJpvswgh33rVmQmqgl+s15BatovgXPvgt0l4FBDqfK5YWq3
A+8EsClmMo16a0UN7fc6rwkyxa7bd4rqi1dk4oXMp/p15szjCxmf1BsXdj+CddZWEQfdc7CwopzmPxQBsJF5ATR1cRaDSjGQDTTGEC9bU7bNGP2vfgvf+PEk4O6yz49887ZNF13wUs32iO/q92pgR9m3bZn6sYYjG2bSdySqe2DjlCy+zKxoOyp9iI/plClC05KJsk6J
XBshH76R7HsP+u0dmU/cTIf8sk2GNjP8Exc5L5wKXQ2ZwLK6I5i0mlNgwDvrSfavM+LqdkTjzhs3fDRD5fyrVXGww8Pm6qqvcquvCjqDCe3V1okgMfn9TCh5JeVVQv4q//PYSritZ71qWfbgqtQ0N1/LCNI+WkZPeR5AFCd2CB8I9pGJExNQqPBZix+9QMz7G9wCrnPe
TEIwzn1PgocHi09PgySCHJnGZhvVMcLDfGr2TTehjbv7Gr0B97dfIDd9f4V/mH7+n+Lq9U0h5hu0BKzNjcmaT7zlcsC3zVLCMDCo6wpY1lJ8xi4RTgojEJYYqnFFddsVCtORtiwajTkOfoHv25IGzPxPIDnFiudL9zH2giY8WfXesdPnxFVkGuD40xof/a/UO2qHwIu0
rL9AqvBaeyQdBncPWHeOyxbUxLsPA34WdLf5bnRw0K89PIGeIe+Shl6ELkVp65BnBOJfuNQnL+kzJfPlxPxRWUSVxCje3axxY/C9Dufy37EXl6bUpivNQH+QaA+wRPULmKGlPNbKizDIYbMDoOH62qvfnUcYebr0l7i8WiwSYWrEA85BYcwzFejzqdMHX7DYPgdLInQN
bA3TaXWEcJ4sBhTqaDu7Dv7zboD9EBDUR6j7hG5eOfmpt8PNLCeo0VxijVWcD1mwGbRltF/9hugyxa+W1sA+HyrTORdzCvxyN1z1Mj82vaSNwww/dRHAez1StcB8K3rfs/8Lf/PMf4SBKjf6MZ0eqMR3roFmmqKp6Oh0dD6tGnxNtlsuhrrfCux+mrOb1tv8zNcLjuN4
ZSsoy0BzqvdF+nZPh8fVCeHPripqmDatIJAC2wX0YWU+C1Ahc6Zq62NfcwsVc4Ke1KwE1Btwxx2rq6hlYw98rKtJ2DAGqj7PeF1e0Yc0cPmbmRCjDplJ0ApIvv+0+C/Rj8gGJ3gQ8NmaomXZl+FNxNMxixcUXImbppipoua/ywrj1qriU8+SZQl09AwhDT5zT3D12KeN
9NZPmZrN6RQ8I3GC5cdikXj9Syvy9R6Syhc1WNhpfAHzJogTBrkY+HQeLQeD4xR8rwic3nLTQ6AvcS5jrZ/KFMo4VDVb56wE301dbZ27lC4wseaYNLLn7hvSVcZM1pybgj0DXrQ0+mpj4j+4Wa3Z9xQsIKFpGg/z5C0GZu7EMfkWLyMVjvQPbTQhD4NdZcN2ZIYHhPWO
8acLac8t8znLoZCmODDyb4LeYe2VEkFBaDslrg5ihih+3n9pqL2OiuqBsQ3N+jDqd36OtAzRszzykfjasohJFi9zk/AveU+c9k4d7mCHRxgCBSgc2lQPcljUtSbsZu/XbPNfQnNAPO2Dt42yZ/D9rDu06ZptwhpQf41IlauWvX0OHaioqWweyy+0Wtsek5fejLPphZTN
ccwHRPvlOYGI4wWyBot84IvAwo+1sVFZgi+ITYaqlw9G7NLvO093ihf2eVTMk9IiCqgSL2iQqkAzPkWoL+PbKpIhAlKA310fmWgTRpcyqpHExK9nw7mza3t/6nm5T3WE5w6I/6eyD9ja4kmohBVWKiB/1TV67wBc1MkMfXDVEwHAXSA7H+7bHana0OVQQnuiqgjaanJ0
KMry1Nu2FggEiXvAjbDMWO4C9pLua+PDAi1wgjOiMPjyVCpyk2FPGMeskwUuHb03m+5VZaTampiy5eYzYPV3eLA9b96ulAPLv2SIrx28KTQrzzu8u0Vgsah+jtKwxxa7flVm27URPwlUi9oRXnL9AKZ2Wg6d0FdNBmXt6+vCl1BWNUVD8w7zkPdG8Dt+szZz6uv3neIr
w9qfcOl2DwSCHiiqDz7qrD1tbGUasjAeJyAZeqgYOI//LSHgFB65EPnVF43yM6r8QpD5Ef+PbzhQcXPOghRNNyCqq4SI1p8VUOMPnT2TRBYWREWGBy565dza3CWVedgn/NwNvfcMAfKYP8WFfSlOs2Iym16TjueBNUJYJW92RW06E+AWJvW3sge2NrYhYlBty0h89lSw
+OGBkYfLqeceIb0f53jkMA4QMI9zi4LmWptawKl0e9oniJMr3z231tDhjGfxN1k2fA9puN/MTLhCOPSSnmxr23pOlB8ZtShHqs4QXHKOGnlLdVl1XuV3XHWFbqJzVluZm9G6N2S7PxN6DP8qck34z6nhi38n4dz3e9hQ9AkVrhRVFaXAqjmF2DCs+77RNPsC0O8iDSPF
2fCFLYHNwBpPoeU+de528vBrvaQm09HmNWzH5liY465vSamOXP0vfmip6g2lkCAIXKrCQ3/y04/vYZ+q/tq8BuzyHsLUEdEWOBb/zm4tZGVdROEkDNXyqCc4R9Fn/GsDO1gN9OdTwKTkP7FrgjAxWb+QnHVy12IyE62n98Qyy+zLfXLGdWmR9Wt31/fMjmX6HXpERjxs
UsESHiGKm13l2Zc8UgLzivhmhsvdSwA5hpugZYc8GWcv3WpOtw+oYz9zl2nuBoR2d9z6PIY+9+nI9w1vCz7B38p3JcL5h659kNeX70tpPxCkPj9gf4Du0OP4iH8oQiCq75pT1f3oisjD3VUdLiokH0Ln3Y2mujFiu8txW3slYvvu/rDnO6PODpPs2bEIlXPI3DGCoKdN
9BK8hVEbQrz8ya437hy+QV3snHnCsgdpqPPy08MtF16nhyTLs4cDe+bVpGIqn6ajBW8hcgKb5wRi4QUHmZI1AOUoskCY5DgczjcUF7ByiUC8B+INAcfgPGIxY14FKG4zpm2jfbBxkXc2CUWeqLgqIKcnqZXZikgKojzuBSED8zth9vqbVhc7G9fG9bJcDSlI/CmKjJHZ
Omf+pva51HZ97ZFSNB4Ba/CPl3Ta/8zT2L87UeYN1CGbvwNhaVlXX+lJxdrb2YxqhcYdSKc2Zc6EcO/7L276fhmdj+nZpipD5A4R3puNuMeQFwhZzxvOuDnqxSIF/yBsricy8lYR9WjTKT/RSeRUOx87aqO6enf93O8pJ/F3G7l0PJ+oWdaUCbqm2K78oSb3Seao7xuZ
Crd8WejCRYBlFAVRBBVA+5k2vmEULhckPTduXZm2DxW2u+uhNkwvRO7kOEX7t6vhOk2ihGxdxaO/gu/hr3Vn2mnMedkjNk8SerfU13f484S07lLggQExH2WA1NtLKOXVWx4e/PWxqbN6iRbjjmEQ4Dvj73w/2ZCz3od06tGYUL5oQqq+qre1Aycf5mzBlMxHXA4ZK5KT
HsHpz50V9mUILW0JfQ6E/GUW3Dq9JsZDzzgQU4Nra5IKDjc8mNct4Jfj/tHL+jHO+9PK4hu3xAdMotkwBj2mVT8eP9sH6sloe7OxsJ0ONG0CZta2CZkHLKCcOkk0lZtMwM43h/59ZUfNjfOB3FXEZjjV9SGi26W03w3TNuNDQ6DNfvvJ38abWxLZ4HTORMLx7o8yKQaS
1Gvo1RZFhlg/uLwu3G3QHtxTMx+ENHo8L82b/azEaBgvE9oszL8q1bC6N0fmMw/NrA2PSkof0QQ1a/tGsL0Y+z6KBLncOkVuU7j0aKkMFyuxW+7g2rEYjEOnVvnP3WfdeziZvnsVk/87MH+Ai7rfpGZR/Li+BAynHFhZXPMwvK1S4tMIG73opzPniF55+PFCpfQ0gKBN
ysNx/EqcKG3LifB1o9n8K+nviohkbD8qkvrZZV6jEA0OD/othF8jfN4v52sinLABeu7tUQBjiYe6h1rhBwiqb7uWbuKJrHwpqG/CkisBbiJFnTLaYeHwMVEASIMnr0ASM32i/xNn0qLlBsv3GppgFF4gtYvqwXr5w116+s6r0cJj7YZmB8QeN2/uRlGO25BnU8trsIDo
Vu8Pthn9vTI5qNPgDP7EcAbWzFr3v5m+G7xBQfCOHV0+nRQiUXoUZ2AYbbR9D352fJdRzPFMOUhgxdloVwy7CC7cR0d3/lxQ1NjpDGAqCvTmpsLUgsES8VgrbhnEbfMyUZfj/TbrHFn3ol7H3sH8a8kSg+Tw7Q+ua7VFEJHhCCrTark5cv+zKZprfm77YZLEEXDDomMG
Vkhuj7S09soKGDfb8yyxNA7jlr9/aiq35IdQInkmllORoyqwx+PkesEdxmWfS25kn31aLoReuxlxiZlfWnMPPUz9XfAPvhhZwUlu5hq94g6cJi40YA/HyGx77A62LNyTDY2f7UWV7AcEjoeMkcH627DHTjvoXqqixAYSJ26pp0o9gmbNaW0+DbyJ8+O+9t4ox8bcf9cg
cqy2V/3dLNQy0t2/mLu3147n5q12c3eTXFGx7EGq6K5odWTZHGLo/a2x2m/M9HsHxDnYoftxQe7+1uQ2KB7TG2MO9jhCo4sw7aLWG91lR5ExUZy7MqFv4QCQhWW0n7Xe+Rb6R958bzvmcGVHPq3XeXDx/Ms4Ri/8RcKpogXEzmPtDebV+jQcs+h6CV77YVQe6m3Wr11T
Mt0QRc7Dly+3/NhiuXisMGVa2gfisMBtwvfCa8PrgkCaPHd72dvNFT9A2tigtKLIpdfd+AnorcF+bsXc4Ta0YrTa6f4lIiAS4+h7X1C3sYgoJ6nDka2HoQ2o8jVF2HJF1VnPGqTe/hNnQQGR2EExF5Ff9qr7E2yIjYvCXXvBKjC9VS3c/qWbb2iuc9H+7zerFF+CVSKj
c4P4Geuhk0m+0IyRqwMKsWCxok2vkV57/LdAMu/RAtKY0vEbQvfZGp9py/gY9l8I4x0XrcD5r6yM1uCV9p3wkuw9Un206d8sJiDz0B6hxZ5oYeA2ScHxCoeuZ5gbs+2PjJ5Cfz4VtFB7U64oxUR9VnbGBGCpsPR1Gi6OX1T9hrXQYq61NAb/n+C8Lac3Wj2vqKsq9/2z
r79YgONA4G3xLrjkmGEqQttfO8Cnn6V8WszMhiFUoWJsf9DE5amKM7mHUm33lrVcP+kB9rM48oJF2wdyjpxIrsRU/Y1DNXYPDvc8Wq4MGNVUTwhmU94SmmBcCyJP0hovK2rs5LxaKhY3nOwH1R6E3GzwapsVVEEOLiDGdkJmxib7zw5J4BTsLcgDoctpxBoAdNfNBCYk
ri7bEn63KsyMRFx0Af0Ih2Y1YdTBC7rr38OKfTheu9PqugfLqGntN0woL9FuDOF932Fvu5KUkeAlxzVrsVE4c7VLI2+Zj83TkXKDLedfSEd8hvyQ6upryrO1gOaDUfzk5JziGG9QxdLZOwtJTsLMBY/3mBYLEKsJoCUcG/PEbiJ+hmnBS+zvDx1abm9pTGDHb+Lml8Zo
NirJX3wtt04Al9ofKBPtP2Mfme+CbSpjm1he7rwMyw55fYiMaG6oKn0Bj4kPMyE4JzYnNZvKnDrPZR+vKMK9r1VnzwOoazsEAFh2RbBQgkvOrYQyZ91vGtIfEZTAWEa+IDBP2z3Rn3X9mXeSPmlFSPSCc+tTQLFC/oUBK9evUSoKDsjXB7IGvjxwCRr7RxGbNkbZw2vr
1rVDoC6ntMKPRCQVwJkpanh33Qye83cjJBExSEI0KKqxSNSThy5cuWWMnvS6CGkCSx9LwYGiV7qGfmLQC0KzB6qIgQS2XrAlCeGEFei2Jxhq1KLjlblfuf9RcLB3fxY3p2YHlKXhYehJVBajJ9iXuOXGkdVwRzt+/Sw9EDTiLAw6Q597hCU+4rc3zHHm6G/MtpOCTfs6
N3s+6cbK9FiCEFIgpbh9FXJnTXPAUp6O28yfHnUcoPSKgoqqeSpKYSoASmhSjaDceTRFxauD6dqAA4bP2EuhzgwJqVnDYlEFhhNrsMJ1lMEaRaVKbbALRNQucAsMwnR4FzUdl66Rez0ggDmh2qGVf81iyFPiHhQGh+gIdUBfGxnAR8eM3TD5KBr3GdWi6o9+kFS2gcOQ
DbfN025aUMQjGDBiqxiipSlpzsqlwlWQz93Wrdq+O/kjfPRG8/TKp9QooKJNw8Lyvy9geBKNPN2NDVBXfoGvbPk/oFxaxRi1ALkrhLIVEy/Jj/a+WrsdAZNIgxamxuPvv9APj/agZuZXdu03m7PvvjciHP5+oQ7qER2+5W+0fJ39A9+JdCjxldRu0LkVQz9dYP7w300E
KUP1Ao/l4IfxljBZGHGOWCvSXpJ6Kj6A2ddlQ9d1diSxBP6R/cBPnMl4z0bSKLPxQ9nRDpDPUgOFT5nfc9w/Rdduvhf3/B/T06dd2XDC06Y4zzDpl/SpVA360MXUvXvcvwtRk698JWOsuTDm5/r74/g5XQnz4bJXeQwG5wHtWvz3qBREQRCizbJSIfNEf9qYRAsiX4TK
3QwJt7+gamRSY/JjXvKzmhChfIy13XEbuZsHfpXHAPD5TKE0KE6dlRts6Ur1BesjEvJYPUwCKrKjMqqAQxez3gQVRd7N4ESCCJPcqQLKjKyd0z2ftuiaxt+p1vz9P5XqfmTHWDXwDn/JA+yterIRdwLrIHxKgxraGiD2XKvRS1z5FsX9zD9LfMO/1EAzQJMtgi6S/GI4
z1UTnUdCeX51g0IEBxMPfBLVWlQY1Tq3imLKcIdOwPGrPUz+LbTq53ZTOA+t6rX6ydv2UzJOKbar1XAhb6+YjObEh59KT3XnHqpWjcK4tR8S3eF73nKv4u6lge1gLfounwRARelTLVTvcVHJm45b7d8f36nL6uOrelZ7zJAPvNURO3ZOVVkgvmef5fylzckkxw5L2uPz
jK5g5/j346XSpvvN9pufK3vi3+xBuoOej4MUSiIN6xKF8wNRBWtEQ+aG3AuQ5T0bRqT6RvdNXgGLAmLIKLCKLPZsswhDb7OnNRnfVjwAfng7kkXyjzkDyZ1GnyjseaGA5YcXFxPf0gOFwXClzDe9OmJitkZGAeVkrZBlZwKzHHcwdL1V85iZn4ufUJyDAUjyAbBNjbbZ
b7z3dT2p+Oy9uBfb+SNM0sVGLFgj5JpCkD445vDa2DGlC4SkQlIolQbVBAhVU743RNZE9V/18t0eX2eb09QzPP0ZufEbdtavd7294p/dNdfq7LNbH9M1T9TG5CA3ctzL5jY+8ruDUynn1TmmMydNkNvt6aWU4U5iOxTXzTVmp6+OptB932ZTn/R91JqOXA4TBphBVUUW
YZummHML5XwOYmShHzP6rrK1L4WNdEQC6H4+jHqUz9DlmthmLpMfn426+9BbC3ucsJ8jpFVVXPVVVVSqvoFhFVbCpJJQEkklpGM+l4fsKYEPG9xYn3r2BU51+jDqzywxw/k6VM2FRYOvsFWDcsjcqZMUp1uh3W6Md5UIHi+h+Pw7NbdvY9SH644jm3ro3CfcmQurfYEf
6+2jG9T/cNA0L3ZZlaufVEuv8Y3/4u5IpwoSH6vB8oA=
EOF
    chmod 755 "${TMP_DIR}/duti"
}
function cleanup_duti() {
    if [[ ! -z "${TMP_DIR}" ]] ; then
        rm -rf "${TMP_DIR}"
    fi
}
trap cleanup_duti EXIT
if ! command_exists duti ; then
    extract_duti
    export PATH="${TMP_DIR}:${PATH}"
fi

for ext in $(cat "${APP_PATH}/Contents/Info.plist" | egrep '\t\t\t\t<string>[a-z0-9]{3,5}</string>' | sed 's|.*<string>\(.*\)</string>|\1|') ; do
    duti -s ${BUNDLE_ID} ${ext} viewer
done
