#!/usr/bin/env python3
import os
import subprocess
import sys


def main():
    dir_path = os.path.abspath(os.path.dirname(__file__))
    shortlog = subprocess.check_output(['git', 'shortlog', '-s', '-e'], cwd=dir_path).decode('utf-8')
    contributors = []
    for line in shortlog.splitlines():
        contributors.append(line.split('\t')[1].strip())

    file_path = os.path.join(dir_path, 'Contributors.h')
    with open(file_path, 'w') as file:
        file.write('// This file is autogenerated by {}.\n'.format(sys.argv[0]))
        file.write('\n')
        file.write('#include <QStringList>\n')
        file.write('\n')
        file.write('static const QStringList CONTRIBUTORS = QStringList()\n')
        for contributor in contributors:
            contributor_safe = ''
            for c in contributor.encode('utf-8'):
                contributor_safe = contributor_safe + '\\x{:02x}'.format(c)
            file.write('    << QString::fromUtf8("{}") // {}\n'.format(contributor_safe, contributor))
        file.write('    ;\n')

    return 0


if __name__ == '__main__':
    sys.exit(main())
